@@ -29,7 +29,7 @@ from .transport import Transport
 try:
     import aiohttp
 
-    from .aiohttp import AioHttpTransport, aiohttp_middleware_factory, aiohttp_timeout
+    from .aiohttp import AioHttpDnsResolver, AioHttpTransport, aiohttp_middleware_factory, aiohttp_timeout
 except ImportError:
     pass
 
@@ -40,7 +40,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "0.1.4"
+__version__ = "0.1.6"
 
 version = f"{__version__}, Python {sys.version}"
 
