@@ -1,7 +1,7 @@
 import asyncio
 import contextlib
-from collections.abc import Callable, Collection, Iterable, Mapping
-from typing import Any, Optional, Protocol, TypeVar, Union
+import sys
+from typing import Any, Callable, Collection, Dict, Iterable, List, Mapping, Optional, Protocol, TypeVar, Union
 
 import yarl
 
@@ -24,15 +24,45 @@ async def close_single(item: TClosable) -> None:
 T = TypeVar("T")
 
 
-async def close_futures(items: Collection[asyncio.Future[T]], as_close: Callable[[T], TClosable]) -> None:
-    for item in items:
-        if item.cancelled():
-            continue
-        try:
-            await close_single(as_close(await item))
-        except asyncio.CancelledError:
-            if not item.cancelled():
-                raise
+if sys.version_info >= (3, 9, 0):
+
+    async def close_futures(items: Collection[asyncio.Future[T]], as_close: Callable[[T], TClosable]) -> None:
+        for item in items:
+            if item.cancelled():
+                continue
+            try:
+                await close_single(as_close(await item))
+            except asyncio.CancelledError:
+                if not item.cancelled():
+                    raise
+
+    async def cancel_futures(futures: Collection[asyncio.Future[T]]) -> None:
+        for future in futures:
+            if future.done():
+                continue
+            future.cancel()
+
+
+else:
+
+    async def _close_futures_py38(items: Collection[Any], as_close: Callable[[Any], TClosable]) -> None:
+        for item in items:
+            if item.cancelled():
+                continue
+            try:
+                await close_single(as_close(await item))
+            except asyncio.CancelledError:
+                if not item.cancelled():
+                    raise
+
+    async def _cancel_futures_py38(futures: Collection[Any]) -> None:
+        for future in futures:
+            if future.done():
+                continue
+            future.cancel()
+
+    close_futures = _close_futures_py38
+    cancel_futures = _cancel_futures_py38
 
 
 async def close(items: Collection[TClosable]) -> None:
@@ -40,13 +70,6 @@ async def close(items: Collection[TClosable]) -> None:
         await close_single(item)
 
 
-async def cancel_futures(futures: Collection[asyncio.Future[T]]) -> None:
-    for future in futures:
-        if future.done():
-            continue
-        future.cancel()
-
-
 def substitute_path_parameters(url: yarl.URL, parameters: Optional[PathParameters] = None) -> yarl.URL:
     if not parameters:
         return url
@@ -55,7 +78,7 @@ def substitute_path_parameters(url: yarl.URL, parameters: Optional[PathParameter
     for name, value in parameters.items():
         path = path.replace(f"{{{name}}}", str(value))
 
-    build_parameters: dict[str, Any] = dict(
+    build_parameters: Dict[str, Any] = dict(
         scheme=url.scheme,
         user=url.user,
         password=url.password,
@@ -69,8 +92,8 @@ def substitute_path_parameters(url: yarl.URL, parameters: Optional[PathParameter
     return yarl.URL.build(**{k: v for k, v in build_parameters.items() if v is not None})
 
 
-def build_query_parameters(query_parameters: QueryParameters) -> dict[str, Union[str, list[str]]]:
-    parameters: dict[str, Union[str, list[str]]] = {}
+def build_query_parameters(query_parameters: QueryParameters) -> Dict[str, Union[str, List[str]]]:
+    parameters: Dict[str, Union[str, List[str]]] = {}
     for name, value in query_parameters.items() if isinstance(query_parameters, Mapping) else query_parameters:
         if value is None:
             continue
